The resulting bus name will be org.mpris.MediaPlayer2.<bus_name_suffix>, where
<bus_name_suffix> must be a unique identifier, such as one based on a UNIX process id.
For example, this could be:
org.mpris.MediaPlayer2.vlc.instance7389
Note: According to the D-Bus specification, the unique identifier “must only contain
the ASCII characters [A-Z][a-z][0-9]_-” and “must not begin with a digit”.
Whether to allow clients to modify the playback rate of the player.
If set to true, the playback rate will be locked the value saved in cache the player state,
or set to the default value of 1.0 (regular speed) if it’s not cached.